@@ -3,20 +3,20 @@ import dpss
 
 def test_find_subset():
     assert dpss.find_subset([1, 2, 3, 4, 5], 6, 3) == [
-        [3, 2, 1], [4, 2], [5, 1]]
+        [1, 5], [2, 4], [1, 2, 3]]
 
 
 def test_find_subset_fast_only_positive():
     assert dpss.find_subset_fast_only_positive([1, 2, 3, 4, 5], 10, 4) == [
-        [4, 3, 2, 1], [5, 3, 2], [5, 4, 1]]
+        [1, 4, 5], [2, 3, 5], [1, 2, 3, 4]]
 
 
 def test_sequence_matcher():
     assert dpss.sequence_matcher([3, 5, 7], [1, 5, -3, 4, 5, 3], 4) == \
         [
-            [(3, [3]), (5, [5]), (7, [5, 4, -3, 1])],
-            [(3, [3]), (5, [4, 1]), (7, [5, 5, -3])],
-            [(3, [5, -3, 1]), (5, [5]), (7, [3, 4])],
+            [(3, [3]), (5, [5]), (7, [-3, 1, 4, 5])],
+            [(3, [3]), (5, [1, 4]), (7, [-3, 5, 5])],
+            [(3, [-3, 1, 5]), (5, [5]), (7, [3, 4])],
     ]
 
 
